package cn.iocoder.yudao.module.delivery.controller.admin;

import cn.iocoder.yudao.module.delivery.entity.Employee;
import cn.iocoder.yudao.module.delivery.entity.EmployeePageReq;
import cn.iocoder.yudao.module.delivery.service.AllWriteOffService;
import cn.iocoder.yudao.module.delivery.service.EmployeeService;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import javax.validation.*;

import io.swagger.v3.oas.annotations.Operation;


/**
 * (Employee)表控制层
 *
 * @author lanbm
 * @since 2024-03-27 21:25:55
 */
@RestController
@RequestMapping("/my/test")
public class EmployeeController {
    /**
     * 服务对象
     */
    @Resource
    private EmployeeService employeeService;

    @Resource
    private AllWriteOffService allWriteOffService;


    /**
     * 新增数据
     *
     * @param employee 实体
     * @return 新增结果
     */
    @PostMapping("/create")
    public CommonResult<Long> create(@Valid @RequestBody Employee employee) {
        return success(employeeService.create(employee));
    }


    /**
     * 编辑数据
     *
     * @param employee 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public CommonResult<Boolean> update(@RequestBody Employee employee) {
        employeeService.update(employee);
        return success(true);
    }


    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */

    @GetMapping("/delete")
    public CommonResult<Boolean> delete(@RequestParam Long id) {
        employeeService.delete(id);
        return success(true);
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("/get")
    public CommonResult<Employee> getModel(@RequestParam("id") Long id) {
        Employee employee = employeeService.getModel(id);
        return success(employee);
    }

    /**
     * 查询所有数据
     *
     * @return 实例对象集合
     */
    @GetMapping
    public CommonResult queryAll() {
        return success(this.employeeService.list());
    }

    /**
     * 分页查询
     *
     * @return 分页对象集合
     */

    @GetMapping("/page")
    @Operation(summary = "获取分页查询列表")
    public CommonResult<PageResult<Employee>> getListPage(@Valid EmployeePageReq PageReq) {
        return success(this.employeeService.getListPage(PageReq));
    }

    /*
    测试调用无参数的存储过程
     */
    @GetMapping("/1")
    public CommonResult test() {
        return success(allWriteOffService.ttest());
    }


}

