package cn.iocoder.yudao.module.delivery.controller.admin;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.json.JsonUtils;
import cn.iocoder.yudao.module.delivery.entity.*;
import cn.iocoder.yudao.module.delivery.entity.bar.CustomerReportBar;
import cn.iocoder.yudao.module.delivery.entity.bar.SalesReportBar;
import cn.iocoder.yudao.module.delivery.entity.bar.series;
import cn.iocoder.yudao.module.delivery.entity.bar.yAxis;
import cn.iocoder.yudao.module.delivery.service.SalesReportService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

/**
 * 销售统计报表控制层
 *
 * @author lanbm
 * @since 2024-03-27
 */
@RestController
@Api(tags = "管理后台 -统计报表")
@RequestMapping("/Report/SalesReport")
public class SalesReportControl {

    //ecw_order_departure 订单始发地
    //ecw_order_consignor 订单发货人
    //ecw_order_consignee 订单收货人

    //订单表 ecw_order
    //drawee 付款人 付款人：1 发货人 2 收货人 3 自定义
    //status 订单状态 0草稿 2待入仓，3入参中

    @Autowired
    private SalesReportService salesReportService;

    /*
     首次成交的客户数统计
     lanbm 2024-04-01
     */
    @PostMapping("/FirstCustomerCount")
    public CommonResult<SalesReportCusTarget> FirstCustomerCount(@RequestBody SalesReportReq Req) throws ParseException {
        SalesReportCusTarget nR = salesReportService.FirstCustomerCount(Req);
        return success(nR);
    }

    /*
     lanbm 2024-05-09 add 统计一段时间成交的客户数
     Get请求一定要注意参数类型
     */
    @GetMapping("/CustomerTargetCount")
    public CommonResult<SalesReportCusTarget> CustomerTargetCount(@Valid SalesReportReq Req) throws ParseException {
        SalesReportCusTarget objR = salesReportService.CustomerTargetCount(Req);
        return success(objR);
    }

    /*
    按运输方式统计重量和方数
    lanbm 2024-04-01
    */
    @PostMapping("/SalesReportCount")
    public CommonResult<List<SalesReportResp>> SalesReportCount(@RequestBody SalesReportReq Req) throws ParseException {
        List<SalesReportResp> list = new ArrayList<>();
        Req=salesReportService.getReq(Req);
        SalesReportResp r0 = salesReportService.SalesReportCount(Req);
        SalesReportResp r1 = salesReportService.SalesReportCountSea(Req);
        SalesReportResp r3 = salesReportService.SalesReportCountAir(Req);
        list.add(r0);
        list.add(r1);
        list.add(r3);
        return success(list);
    }

    /*
     图表分析统计结果
     lanbm 2024-04-01 add
     */
    @PostMapping("/SalesReportList")
    public CommonResult<SalesReportCusTarget> SalesReportList(@RequestBody SalesReportReq Req) throws ParseException {
        SalesReportCusTarget objR = salesReportService.FirstCustomerCount(Req);
        return success(objR);
    }

    /*
    获取销售分析图表数据
     */
    @GetMapping("/getEChartData")
    public CommonResult<SalesReportBar>
    getEChartData(@Valid SalesReportReq query) throws ParseException {
        SalesReportBar ReportBar = salesReportService.getCustomerReportBar(query);
        return success(ReportBar);
    }


}
