package cn.iocoder.yudao.module.delivery.utility;

import cn.hutool.core.annotation.AnnotationUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.TypeReference;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONUtil;
import cn.iocoder.yudao.module.delivery.entity.Employee;
import cn.iocoder.yudao.module.delivery.entity.deptex.TreeNode;
import com.alibaba.fastjson.JSON;
import org.springframework.web.bind.annotation.RequestMapping;

import java.math.BigDecimal;
import java.util.*;

/*
 递归的例子 lanbm 2024-05-26 add
 */
public class JsonFactory {
    public static List<TreeNode> buildtree(List<TreeNode> nodes, int id) {
        List<TreeNode> treeNodes = new ArrayList<TreeNode>();
        for (TreeNode treeNode : nodes) {
            TreeNode node = new TreeNode();
            node.setId(treeNode.getId());
            node.setText(treeNode.getText());
            if (id == treeNode.getFid()) {
                //递给调用buildtree方法给TreeNode中的children属性赋值
                node.setChildren(buildtree(nodes, node.getId()));
                treeNodes.add(node);
            }
        }
        return treeNodes;
    }

    /*
     获取UUID lanbm 2024-05-30 添加
     */
    public static String getUUID()
    {
        return UUID.randomUUID().toString();
    }


    /*
     日期相关的通用工具类
     https://blog.csdn.net/weixin_53742691/article/details/134064426
     */
    public static void test1() {
        //Date、long、Calendar之间的相互转换
        //当前时间
        Date date = DateUtil.date();

        //Calendar转Date
        date = DateUtil.date(Calendar.getInstance());

        //时间戳转Date
        date = DateUtil.date(System.currentTimeMillis());
        //自动识别格式转换
        String dateStr = "2017-03-01";
        date = DateUtil.parse(dateStr);

        //自定义格式化转换
        date = DateUtil.parse(dateStr, "yyyy-MM-dd");
        //格式化输出日期
        String format = DateUtil.format(date, "yyyy-MM-dd");
        //获得年的部分
        int year = DateUtil.year(date);
        //获得月份，从0开始计数
        int month = DateUtil.month(date);
        //获取某天的开始、结束时间
        Date beginOfDay = DateUtil.beginOfDay(date);
        Date endOfDay = DateUtil.endOfDay(date);
        //计算偏移后的日期时间
        Date newDate = DateUtil.offset(date, DateField.DAY_OF_MONTH, 2);
        //计算日期时间之间的偏移量
        long betweenDay = DateUtil.between(date, newDate, DateUnit.DAY);
    }

    /*
     字符串相关的通用工具类
     */
    public static void test2() {
        //判断是否为空字符串
        String str = "test";
        StrUtil.isEmpty(str);
        StrUtil.isNotEmpty(str);

        //去除字符串的前后缀
        StrUtil.removeSuffix("a.jpg", ".jpg");
        StrUtil.removePrefix("a.jpg", "a.");

        //格式化字符串
        String template = "这只是个占位符:{}";
        String str2 = StrUtil.format(template, "我是占位符");
        // LOGGER.info("/strUtil format:{}", str2);
    }

    public static void test3() {
        double n1 = 1.234;
        double n2 = 1.234;
        double result;

        //对float、double、BigDecimal做加减乘除操作
        result = NumberUtil.add(n1, n2);
        result = NumberUtil.sub(n1, n2);
        result = NumberUtil.mul(n1, n2);
        result = NumberUtil.div(n1, n2);

        //保留两位小数
        BigDecimal roundNum = NumberUtil.round(n1, 2);
        String n3 = "1.234";

        //判断是否为数字、整数、浮点数
        NumberUtil.isNumber(n3);
        NumberUtil.isInteger(n3);
        NumberUtil.isDouble(n3);
        //BeanUtil
        //JavaBean的工具类，可用于Map与JavaBean对象的互相转换以及对象属性的拷贝。

        //PmsBrand brand = new PmsBrand();
        //brand.setId(1L);
        //brand.setName("小米");
        // brand.setShowStatus(0);

        //Bean转Map
        //Map<String, Object> map = BeanUtil.beanToMap(brand);
        //LOGGER.info("beanUtil bean to map:{}", map);

        //Map转Bean
        //PmsBrand mapBrand = BeanUtil.mapToBean(map, PmsBrand.class, false);
        //LOGGER.info("beanUtil map to bean:{}", mapBrand);

        //Bean属性拷贝
        //PmsBrand copyBrand = new PmsBrand();
        //BeanUtil.copyProperties(brand, copyBrand);
        //LOGGER.info("beanUtil copy properties:{}", copyBrand);
    }

    public static void test4() {
        //将多个键值对加入到Map中
        Map<Object, Object> map = MapUtil.of(new String[][]{
                {"key1", "value1"},
                {"key2", "value2"},
                {"key3", "value3"}
        });

        //判断Map是否为空
        MapUtil.isEmpty(map);
        MapUtil.isNotEmpty(map);

        // AnnotationUtil 注解工具类，可用于获取注解与注解中指定的值。

        //获取指定类、方法、字段、构造器上的注解列表
        // Annotation[] annotationList = AnnotationUtil.getAnnotations(HutoolController.class, false);
        // LOGGER.info("annotationUtil annotations:{}", annotationList);

        //获取指定类型注解
        // Api api = AnnotationUtil.getAnnotation(HutoolController.class, Api.class);
        // LOGGER.info("annotationUtil api value:{}", api.description());
        //获取指定类型注解的值
        //Object annotationValue = AnnotationUtil.getAnnotationValue(HutoolController.class,
        //               RequestMapping.class);
    }

    /*
     字符串和对象的相互转换
     */
    public static void test5() {
        //对象转字符串
        Employee e=new Employee();
        String userInfoStr = JSONUtil.toJsonStr(e);
        //log.info("对象转字符串userInfoStr：{}", userInfoStr);

        //生成token
        //String jwtToken = TokenUtil.createJwtToken(userInfoStr);

        //字符串转对象
        Employee userInfo = JSONUtil.toBean(userInfoStr, Employee.class);
        List<Employee> userMapList=new ArrayList<>();
        // HuTool
        List<Employee> userList =
                JSONUtil.toList(new JSONArray(userMapList),Employee.class);
        // 同fastjson
        /*
        List<Employee> userList2 =
                JSON.parseObject(JSON.toJSONString(userMapList)
                        ,new TypeReference<>() {});

         */


        String uuid = IdUtil.simpleUUID(); // 生成简单UUID

        BigDecimal num1 = new BigDecimal("10.5");
        BigDecimal num2 = new BigDecimal("5.2");
        BigDecimal result = NumberUtil.add(num1, num2);
        //使用BigDecimal进行精确运算


        //Map<String,Integer> originalMap = new HashMap<>();
        //Map<Integer, String> swappedMap = CollUtil.reverse(originalMap);
        //交换Map的键和值

    }

}

